summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/chatview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/chatview.h')
-rw-r--r--kopete/kopete/chatwindow/chatview.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/kopete/chatwindow/chatview.h b/kopete/kopete/chatwindow/chatview.h
index 039918dd..29aa5d17 100644
--- a/kopete/kopete/chatwindow/chatview.h
+++ b/kopete/kopete/chatwindow/chatview.h
@@ -56,7 +56,7 @@ class ChatView : public KDockMainWindow, public KopeteView
Q_OBJECT
TQ_OBJECT
public:
- ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *tqparent, const char *name = 0 );
+ ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *parent, const char *name = 0 );
~ChatView();
/** the state of our chat */
@@ -105,10 +105,10 @@ public:
void setCaption( const TQString &text, bool modified );
/**
* Changes the pointer to the chat window. Used to re-tqparent the view
* @param tqparent The new chat window
*/
- void setMainWindow( KopeteChatWindow* tqparent );
+ void setMainWindow( KopeteChatWindow* parent );
/**
* Returns the message currently in the edit area
@@ -120,7 +120,7 @@ public:
/**
* Sets the current message in the chat window
* @param tqparent The new chat window
*
* Reimplemented from KopeteView
*/
@@ -301,7 +301,7 @@ signals:
void canSendChanged(bool);
/**
* Emitted when we re-tqparent ourselves with a new window
*/
void windowCreated();
@@ -412,7 +412,7 @@ private:
class ChatWindowPlugin : public Kopete::ViewPlugin
{
public:
- ChatWindowPlugin(TQObject *tqparent, const char *name, const TQStringList &args);
+ ChatWindowPlugin(TQObject *parent, const char *name, const TQStringList &args);
KopeteView* createView( Kopete::ChatSession *manager );
};
@@ -105,10 +105,10 @@ public:
void setCaption( const TQString &text, bool modified );
/**
- * Changes the pointer to the chat window. Used to re-tqparent the view
- * @param tqparent The new chat window
+ * Changes the pointer to the chat window. Used to re-parent the view
+ * @param parent The new chat window
*/
@@ -120,7 +120,7 @@ public:
/**
* Sets the current message in the chat window
- * @param tqparent The new chat window
+ * @param parent The new chat window
*
* Reimplemented from KopeteView
@@ -301,7 +301,7 @@ signals:
void canSendChanged(bool);
/**
- * Emitted when we re-tqparent ourselves with a new window
+ * Emitted when we re-parent ourselves with a new window
*/
void windowCreated();